"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.MessageService__Consumer = exports.MessageService__Producer = void 0;
const soa_client_1 = require("@cross-lab-project/soa-client");
const soa_client_2 = require("@cross-lab-project/soa-client");
const tiny_typed_emitter_1 = require("tiny-typed-emitter");
const ServiceType = 'https://api.goldi-labs.de/serviceTypes/message';
function checkConfig(config) {
    if (config.serviceType !== ServiceType) {
        //throw Error("Service Configuration needs to be for MessageService type");
    }
}
class MessageService__Producer {
    constructor(serviceId) {
        this.serviceType = ServiceType;
        this.serviceDirection = soa_client_1.Producer;
        this.serviceId = serviceId;
    }
    getMeta() {
        return {
            serviceType: this.serviceType,
            serviceId: this.serviceId,
            serviceDirection: this.serviceDirection,
        };
    }
    setupConnection(connection, serviceConfig) {
        checkConfig(serviceConfig);
        const channel = new soa_client_2.DataChannel();
        if (connection.tiebreaker) {
            connection.transmit(serviceConfig, 'data', channel);
        }
        else {
            connection.receive(serviceConfig, 'data', channel);
        }
        this.channel = channel;
    }
    async sendMessage(message, messageType) {
        if (this.channel !== undefined) {
            await this.channel.ready();
            this.channel.send(JSON.stringify({ messageType: messageType, message: message }));
        }
    }
}
exports.MessageService__Producer = MessageService__Producer;
class MessageService__Consumer extends tiny_typed_emitter_1.TypedEmitter {
    constructor(serviceId) {
        super();
        this.serviceType = ServiceType;
        this.serviceDirection = soa_client_1.Consumer;
        this.serviceId = serviceId;
    }
    getMeta() {
        return {
            serviceType: this.serviceType,
            serviceId: this.serviceId,
            serviceDirection: this.serviceDirection,
        };
    }
    setupConnection(connection, serviceConfig) {
        checkConfig(serviceConfig);
        const channel = new soa_client_2.DataChannel();
        channel.ondata = this.handleData.bind(this);
        if (connection.tiebreaker) {
            connection.transmit(serviceConfig, 'data', channel);
        }
        else {
            connection.receive(serviceConfig, 'data', channel);
        }
    }
    handleData(data) {
        if (typeof data === 'string') {
            const msg = JSON.parse(data);
            this.emit('message', { message_type: msg.messageType, message: msg.message });
        }
    }
}
exports.MessageService__Consumer = MessageService__Consumer;
//# sourceMappingURL=message_service.js.map